def add_polynomials(poly1, poly2):
    """
    두 다항식을 더합니다.
    
    Parameters:
        poly1 (list): 첫 번째 다항식의 계수 리스트
        poly2 (list): 두 번째 다항식의 계수 리스트
    
    Returns:
        str: 두 다항식의 덧셈 결과 다항식 수식
    """
    max_degree = max(len(poly1), len(poly2))
    result = [0] * max_degree

    for i in range(len(poly1)):
        result[i] += poly1[i]

    for i in range(len(poly2)):
        result[i] += poly2[i]

    return polynomial_expression(result)

def subtract_polynomials(poly1, poly2):
    """
    두 다항식을 뺍니다.
    
    Parameters:
        poly1 (list): 첫 번째 다항식의 계수 리스트
        poly2 (list): 두 번째 다항식의 계수 리스트
    
    Returns:
        str: 두 다항식의 뺄셈 결과 다항식 수식
    """
    max_degree = max(len(poly1), len(poly2))
    result = [0] * max_degree

    for i in range(len(poly1)):
        result[i] += poly1[i]

    for i in range(len(poly2)):
        result[i] -= poly2[i]

    return polynomial_expression(result)

def polynomial_expression(coefficients):
    """
    리스트를 다항식 수식으로 표현합니다.
    
    Parameters:
        coefficients (list): 다항식의 각 항의 계수를 포함하는 리스트
    
    Returns:
        str: 다항식의 수식 문자열
    """
    degree = len(coefficients) - 1  # 다항식의 차수
    expression = ""

    for i, coef in enumerate(coefficients):
        # 상수항 처리
        if i == degree:
            expression += str(coef)
        else:
            # 계수가 0이면 해당 항은 표시하지 않음
            if coef == 0:
                continue

            # 계수가 1이면 계수 부분은 생략
            if coef == 1:
                expression += "x"
            else:
                expression += str(coef) + "x"

            # 차수가 1보다 크면 차수를 표시
            if degree - i > 1:
                expression += "^" + str(degree - i)

        # 항 사이에 + 또는 - 추가
        if i != degree:
            if coefficients[i + 1] >= 0:
                expression += " + "
            else:
                expression += " - "

    return expression

# 다항식의 계수
poly1 = list(map(int,input('다항식의 개수를 입력하세요.').split()))  # 3x^2 + 2x - 1
poly2 = list(map(int,input('다항식의 개수를 입력하세요.').split()))  # x^3 + 2x^2 + 4

print(polynomial_expression(poly1))
print(polynomial_expression(poly2))

# 두 다항식의 덧셈
addition_result = add_polynomials(poly1, poly2)
print("두 다항식의 덧셈 결과:", addition_result)

# 두 다항식의 뺄셈
subtraction_result = subtract_polynomials(poly1, poly2)
print("두 다항식의 뺄셈 결과:", subtraction_result)
